/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { CheckBoxRounded, InputSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * Represents the directive that renders the [Kendo UI CheckBox]({% slug overview_checkbox %}) input component.
 * The directive is placed on input type="checkbox" elements.
 *
 * @example
 * ```ts-no-run
 * <input type="checkbox" kendoCheckBox />
 * ```
 */
export declare class CheckBoxDirective {
    private renderer;
    private hostElement;
    kendoClass: boolean;
    /**
     * The size property specifies the width and height of the CheckBox
     * ([see example]({% slug appearance_checkboxdirective %}#toc-size)).
     *
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     */
    set size(size: InputSize);
    get size(): InputSize;
    /**
     * The rounded property specifies the border radius of the CheckBox
     * ([see example](slug:appearance_checkboxdirective#toc-roundness)).
     *
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     */
    set rounded(rounded: CheckBoxRounded);
    get rounded(): CheckBoxRounded;
    private _size;
    private _rounded;
    constructor(renderer: Renderer2, hostElement: ElementRef);
    ngAfterViewInit(): void;
    private handleClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckBoxDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CheckBoxDirective, "input[kendoCheckBox]", never, { "size": { "alias": "size"; "required": false; }; "rounded": { "alias": "rounded"; "required": false; }; }, {}, never, never, true, never>;
}
