/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnChanges, SimpleChanges, EventEmitter, ElementRef, AfterViewInit, Renderer2, ChangeDetectorRef } from '@angular/core';
import { RGBA } from './models';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { NumericTextBoxComponent } from './../numerictextbox/numerictextbox.component';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { InputSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class ColorInputComponent implements AfterViewInit, OnChanges {
    private host;
    private renderer;
    private cdr;
    localizationService: LocalizationService;
    /**
     * The id of the hex input.
     */
    focusableId: string;
    /**
     * The color format view.
     */
    formatView: string;
    /**
     * The size property specifies the padding of the ColorInput.
     *
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     */
    size: InputSize;
    /**
     * The inputs tabindex.
     */
    tabindex: number;
    /**
     * The color value that will be parsed and populate the hex & rgba inputs.
     * Required input property.
     */
    value: string;
    /**
     * Sets whether the alpha slider will be shown.
     */
    opacity: boolean;
    /**
     * Sets the disabled state of the ColorInput.
     */
    disabled: boolean;
    /**
     * Sets the read-only state of the ColorInput.
     *
     * @default false
     */
    readonly: boolean;
    /**
     * Emits a parsed rgba string color.
     */
    valueChange: EventEmitter<string>;
    /**
     * Emits when the user tabs out of the last focusable input.
     */
    tabOut: EventEmitter<any>;
    colorInputClass: boolean;
    opacityInput: NumericTextBoxComponent;
    hexInput: ElementRef;
    blueInput: NumericTextBoxComponent;
    toggleFormatButton: ElementRef;
    /**
     * The rgba inputs values.
     */
    rgba: RGBA;
    hex: string;
    /**
     * Indicates whether any of the inputs are focused.
     */
    private get isFocused();
    /**
     * Indicates whether any of the rgba inputs have value.
     */
    private get rgbaInputValid();
    /**
     * @hidden
     */
    caretAltExpandIcon: SVGIcon;
    private subscriptions;
    constructor(host: ElementRef, renderer: Renderer2, cdr: ChangeDetectorRef, localizationService: LocalizationService);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    get formatButtonTitle(): string;
    handleRgbaValueChange(): void;
    focusDragHandle(event: any): void;
    handleHexValueChange(hex: string): void;
    handleRgbaInputBlur(): void;
    handleHexInputBlur(): void;
    focusLast(): void;
    onTab(): void;
    private toggleFormatView;
    private initDomEvents;
    private lastInput;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColorInputComponent, "kendo-colorinput", never, { "focusableId": { "alias": "focusableId"; "required": false; }; "formatView": { "alias": "formatView"; "required": false; }; "size": { "alias": "size"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "value": { "alias": "value"; "required": false; }; "opacity": { "alias": "opacity"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; }, { "valueChange": "valueChange"; "tabOut": "tabOut"; }, never, never, true, never>;
}
