/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OutputFormat, HSVA, RGBA } from '../models';
import { RGB } from '../models/rgb';
/**
 * @hidden
 *
 * Returns the hex or rgba string representation of the color.
 */
export declare const parseColor: (value: string, format: OutputFormat, opacityEnabled?: boolean, safe?: boolean) => string;
/**
 * @hidden
 *
 * Returns an HSV object representation of the color string.
 */
export declare const getHSV: (value: string, safe?: boolean) => HSVA;
/**
 * @hidden
 *
 * Returns an RGBA object representation of the color string.
 */
export declare const getRGBA: (value: string, safe?: boolean) => RGBA;
/**
 * @hidden
 *
 * Returns the RGBA string representation of the color.
 */
export declare const getColorFromHSV: (hsva: HSVA, format?: OutputFormat, opacityEnabled?: boolean) => string;
/**
 * @hidden
 *
 * Returns the HEX value.
 */
export declare const getHexValue: (color: any, opacity: boolean) => string;
/**
 * @hidden
 *
 * Returns the RGBA string representation of the color based on the `hue`, assuming the `value`, `saturation` and `alpha` have value of `1`.
 */
export declare const getColorFromHue: (hue: number) => string;
/**
 * @hidden
 *
 * Returns the RGBA string representation of the color.
 */
export declare const getColorFromRGBA: (rgba: RGBA) => string;
/**
 *
 * @hidden
 */
export declare function nameFormat(value: string, safe: boolean): string;
/**
 * @hidden
 *
 * Returns the RGB object representation of the color based on the background color.
 */
export declare const getRGBFromRGBA: (foregroundColor: RGBA, backgroundColor: RGBA) => RGB;
/**
 * @hidden
 *
 * Returns the relative luminance.
 */
export declare const getLuminance: (rgb: RGB) => number;
/**
 * @hidden
 *
 * Returns the color contrast.
 */
export declare const getContrast: (luminance1: number, luminance2: number) => number;
/**
 * @hidden
 *
 * Returns the color contrast from two RGBA colors.
 */
export declare const getContrastFromTwoRGBAs: (a: RGBA, b: RGBA) => number;
