/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { InjectionToken } from "@angular/core";
import { InputStylingClasses } from "./models";
/**
 * @hidden
 *
 * Checks if the value is `null` or `undefined`. Falsy values like '', 0, false, NaN, etc. are regarded as present.
 */
export declare const isPresent: (value: any) => boolean;
/**
 * @hidden
 */
export declare const areSame: (value1: any, value2: any) => boolean;
/**
 * @hidden
 */
export declare const requiresZoneOnBlur: (ngControl: any) => any;
/**
 * @hidden
 *
 * Fits the contender number into the specified bounds. If the number is NaN or null, the min is returned.
 *
 * @param contender Represents the number you want to fit into specified bounds.
 * @param min The inclusive lower bound number.
 * @param max The inclusive upper bound number.
 */
export declare const fitIntoBounds: (contender: number, min: number, max: number) => number;
/**
 * @hidden
 */
export declare const SIZE_MAP: {
    small: string;
    medium: string;
    large: string;
};
/**
 * @hidden
 */
export declare const ROUNDED_MAP: {
    small: string;
    medium: string;
    large: string;
    full: string;
};
/**
 * @hidden
 */
export declare const isNone: (style: string) => boolean;
/**
 * @hidden
 *
 * Returns the styling classes to be added and removed
 */
export declare const getStylingClasses: (componentType: any, stylingOption: string, previousValue: any, newValue: any) => InputStylingClasses;
/**
 * @hidden
 *
 * Used to differentiate between the Radio and CheckBox components in their base class.
 */
export declare const COMPONENT_TYPE: InjectionToken<ComponentType>;
/**
 * @hidden
 */
export type ComponentType = 'radio' | 'checkbox';
/**
 * @hidden
 */
export declare const replaceMessagePlaceholder: (message: string, name: string, value: string) => string;
