/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PrefixTemplateDirective, SuffixTemplateDirective, SeparatorComponent } from "@progress/kendo-angular-common";
import { CheckBoxComponent } from "./checkbox/checkbox.component";
import { CheckBoxDirective } from "./checkbox/checkbox.directive";
import { ColorGradientComponent } from "./colorpicker/color-gradient.component";
import { ColorPaletteComponent } from "./colorpicker/color-palette.component";
import { ColorPickerComponent } from "./colorpicker/colorpicker.component";
import { FlatColorPickerComponent } from "./colorpicker/flatcolorpicker.component";
import { ColorPickerCustomMessagesComponent } from "./colorpicker/localization/custom-messages.component";
import { ErrorComponent } from "./formfield/error.component";
import { FormFieldComponent } from "./formfield/formfield.component";
import { HintComponent } from "./formfield/hint.component";
import { MaskedTextBoxComponent } from "./maskedtextbox/maskedtextbox.component";
import { NumericTextBoxCustomMessagesComponent } from "./numerictextbox/localization/custom-messages.component";
import { NumericTextBoxComponent } from "./numerictextbox/numerictextbox.component";
import { RadioButtonComponent } from "./radiobutton/radiobutton.component";
import { RadioButtonDirective } from "./radiobutton/radiobutton.directive";
import { RangeSliderCustomMessagesComponent } from "./rangeslider/localization/custom-messages.component";
import { RangeSliderComponent } from "./rangeslider/rangeslider.component";
import { RatingHoveredItemTemplateDirective } from "./rating/directives/rating-hovered-item.directive";
import { RatingItemTemplateDirective } from "./rating/directives/rating-item.directive";
import { RatingSelectedItemTemplateDirective } from "./rating/directives/rating-selected-item.directive";
import { RatingComponent } from "./rating/rating.component";
import { InputSeparatorComponent } from "./shared/input-separator.component";
import { TextAreaDirective } from "./shared/textarea.directive";
import { SignatureCustomMessagesComponent } from "./signature/localization/custom-messages.component";
import { SignatureComponent } from "./signature/signature.component";
import { SliderCustomMessagesComponent } from "./slider/localization/custom-messages.component";
import { SliderComponent } from "./slider/slider.component";
import { LabelTemplateDirective } from "./sliders-common/label-template.directive";
import { SwitchCustomMessagesComponent } from "./switch/localization/custom-messages.component";
import { SwitchComponent } from "./switch/switch.component";
import { TextAreaPrefixComponent } from "./textarea/textarea-prefix.component";
import { TextAreaSuffixComponent } from "./textarea/textarea-suffix.component";
import { TextAreaComponent } from "./textarea/textarea.component";
import { TextBoxCustomMessagesComponent } from "./textbox/localization/custom-messages.component";
import { TextBoxPrefixTemplateDirective } from "./textbox/textbox-prefix.directive";
import { TextBoxSuffixTemplateDirective } from "./textbox/textbox-suffix.directive";
import { TextBoxComponent } from "./textbox/textbox.component";
import { TextBoxDirective } from "./textbox/textbox.directive";
import { OTPInputComponent } from "./otpinput/otpinput.component";
import { OTPInputCustomMessagesComponent } from "./otpinput/localization/custom-messages.component";
/**
 * Utility array that contains all `TextBox` related components and directives
 */
export declare const KENDO_TEXTBOX: readonly [typeof TextBoxDirective, typeof TextBoxComponent, typeof InputSeparatorComponent, typeof TextBoxSuffixTemplateDirective, typeof TextBoxPrefixTemplateDirective, typeof TextBoxCustomMessagesComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent];
/**
 * Utility array that contains all `NumericTextBox` related components and directives
 */
export declare const KENDO_NUMERICTEXTBOX: readonly [typeof NumericTextBoxComponent, typeof NumericTextBoxCustomMessagesComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent];
/**
 * Utility array that contains all `MaskedTextBox` related components and directives
 */
export declare const KENDO_MASKEDTEXTBOX: readonly [typeof MaskedTextBoxComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent];
/**
 * Utility array that contains all `OTP` related components and directives
 */
export declare const KENDO_OTPINPUT: readonly [typeof OTPInputComponent, typeof OTPInputCustomMessagesComponent];
/**
 * Utility array that contains all `TextArea` related components and directives
 */
export declare const KENDO_TEXTAREA: readonly [typeof TextAreaComponent, typeof TextAreaDirective, typeof TextAreaPrefixComponent, typeof TextAreaSuffixComponent, typeof SeparatorComponent];
/**
 * Utility array that contains all `CheckBox` related components and directives
 */
export declare const KENDO_CHECKBOX: readonly [typeof CheckBoxComponent, typeof CheckBoxDirective];
/**
 * Utility array that contains all `RadioButton` related components and directives
 */
export declare const KENDO_RADIOBUTTON: readonly [typeof RadioButtonComponent, typeof RadioButtonDirective];
/**
 * Utility array that contains all `Switch` related components and directives
 */
export declare const KENDO_SWITCH: readonly [typeof SwitchComponent, typeof SwitchCustomMessagesComponent];
/**
 * Utility array that contains all `FormField` related components and directives
 */
export declare const KENDO_FORMFIELD: readonly [typeof FormFieldComponent, typeof HintComponent, typeof ErrorComponent];
/**
 * Utility array that contains all `Slider` related components and directives
 */
export declare const KENDO_SLIDER: readonly [typeof SliderComponent, typeof SliderCustomMessagesComponent, typeof LabelTemplateDirective];
/**
 * Utility array that contains all `RangeSlider` related components and directives
 */
export declare const KENDO_RANGESLIDER: readonly [typeof RangeSliderComponent, typeof RangeSliderCustomMessagesComponent, typeof LabelTemplateDirective];
/**
 * Utility array that contains all `Rating` related components and directives
 */
export declare const KENDO_RATING: readonly [typeof RatingComponent, typeof RatingItemTemplateDirective, typeof RatingHoveredItemTemplateDirective, typeof RatingSelectedItemTemplateDirective];
/**
 * Utility array that contains all `Signature` related components and directives
 */
export declare const KENDO_SIGNATURE: readonly [typeof SignatureComponent, typeof SignatureCustomMessagesComponent];
/**
 * Utility array that contains all `ColorPicker` related components and directives
 */
export declare const KENDO_COLORPICKER: readonly [typeof ColorPickerComponent, typeof ColorPickerCustomMessagesComponent];
/**
 * Utility array that contains all `FlatColorPicker` related components and directives
 */
export declare const KENDO_FLATCOLORPICKER: readonly [typeof FlatColorPickerComponent, typeof ColorPickerCustomMessagesComponent];
/**
 * Utility array that contains all `ColorPallete` related components and directives
 */
export declare const KENDO_COLORPALETTE: readonly [typeof ColorPaletteComponent, typeof ColorPickerCustomMessagesComponent];
/**
 * Utility array that contains all `ColorGradient` related components and directives
 */
export declare const KENDO_COLORGRADIENT: readonly [typeof ColorGradientComponent, typeof ColorPickerCustomMessagesComponent];
/**
 * Utility array that contains all `@progress/kendo-angular-inputs` related components and directives
 */
export declare const KENDO_INPUTS: readonly [typeof TextBoxDirective, typeof TextBoxComponent, typeof InputSeparatorComponent, typeof TextBoxSuffixTemplateDirective, typeof TextBoxPrefixTemplateDirective, typeof TextBoxCustomMessagesComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent, typeof NumericTextBoxComponent, typeof NumericTextBoxCustomMessagesComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent, typeof MaskedTextBoxComponent, typeof PrefixTemplateDirective, typeof SuffixTemplateDirective, typeof SeparatorComponent, typeof TextAreaComponent, typeof TextAreaDirective, typeof TextAreaPrefixComponent, typeof TextAreaSuffixComponent, typeof SeparatorComponent, typeof CheckBoxComponent, typeof CheckBoxDirective, typeof RadioButtonComponent, typeof RadioButtonDirective, typeof SwitchComponent, typeof SwitchCustomMessagesComponent, typeof FormFieldComponent, typeof HintComponent, typeof ErrorComponent, typeof SliderComponent, typeof SliderCustomMessagesComponent, typeof LabelTemplateDirective, typeof RangeSliderComponent, typeof RangeSliderCustomMessagesComponent, typeof LabelTemplateDirective, typeof RatingComponent, typeof RatingItemTemplateDirective, typeof RatingHoveredItemTemplateDirective, typeof RatingSelectedItemTemplateDirective, typeof SignatureComponent, typeof SignatureCustomMessagesComponent, typeof ColorPickerComponent, typeof ColorPickerCustomMessagesComponent, typeof FlatColorPickerComponent, typeof ColorPickerCustomMessagesComponent, typeof ColorGradientComponent, typeof ColorPickerCustomMessagesComponent, typeof ColorPaletteComponent, typeof ColorPickerCustomMessagesComponent, typeof OTPInputComponent, typeof OTPInputCustomMessagesComponent];
