/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { InputSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * Represents the directive that renders the [Kendo UI RadioButton]({% slug overview_checkbox %}) input component.
 * The directive is placed on input type="radio" elements.
 *
 * @example
 * ```ts-no-run
 * <input type="radio" kendoRadioButton />
 * ```
 */
export declare class RadioButtonDirective {
    private renderer;
    private hostElement;
    kendoClass: boolean;
    /**
     * The size property specifies the width and height of the RadioButton
     * ([see example]({% slug appearance_radiobuttondirective %}#toc-size)).
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     */
    set size(size: InputSize);
    get size(): InputSize;
    private _size;
    constructor(renderer: Renderer2, hostElement: ElementRef);
    ngAfterViewInit(): void;
    private handleClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<RadioButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RadioButtonDirective, "input[kendoRadioButton]", never, { "size": { "alias": "size"; "required": false; }; }, {}, never, never, true, never>;
}
