/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SeparatorOrientation } from '@progress/kendo-angular-common';
import * as i0 from "@angular/core";
/**
 * Specifies a separator in the content of components like the TextArea and the TextBox. ([see examples]({% slug adornments_textbox %}#toc-separator)).
 * @example
 * ```ts-no-run
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <kendo-textbox>
 *    <ng-template kendoTextBoxSuffixTemplate>
 *        <kendo-input-separator></kendo-input-separator>
 *        <button kendoButton look="clear" icon="image"></button>
 *    </ng-template>
 *  </kendo-textbox>
 * `
 * })
 * class AppComponent {}
 * ```
 */
export declare class InputSeparatorComponent {
    /**
     * Specifies the orientation of the separator. Applicable for the adornments of the [`TextAreaComponent`](slug:api_inputs_textareacomponent).
     *
     * @default 'vertical'
     */
    orientation: SeparatorOrientation;
    get vertical(): boolean;
    get horizontal(): boolean;
    hostClass: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputSeparatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InputSeparatorComponent, "kendo-input-separator, kendo-textbox-separator", never, { "orientation": { "alias": "orientation"; "required": false; }; }, {}, never, never, true, never>;
}
